@@ -121,7 +121,7 @@ class Widget(view.Renderable):
 
     Basic post-initialization consists of caching required CSS and JS
     resources and setting the widget as initialized preventing further
-    modification of it's attributes.
+    modification of its attributes.
 
     .. sourcecode:: python
 
@@ -129,7 +129,7 @@ class Widget(view.Renderable):
         >>> w.a = 'bar'
         Traceback (most recent call last):
             ...
-        WidgetLocked: The widget is locked. It's unthread-safe to alter it's attributes after initialization.
+        WidgetLocked: The widget is locked. It's unthread-safe to alter its attributes after initialization.
 
     Widget attributes can only be modified in this method because widgets
     should behave in a state-less way as they are shared among threads for
