@@ -7,9 +7,9 @@ import os
 import tempfile
 import subprocess
 try:
-        from hashlib import md5 as hash_constructor
-except ImportError:
-        from md5 import new as hash_constructor
+    from hashlib import md5 as hash_constructor
+except ImportError: # Python < 2.5
+    from md5 import new as hash_constructor
 import mimetypes
 
 try:
@@ -25,6 +25,7 @@ from tw.core.resources import registry, merge_resources, _JavascriptFileIter
 
 from tw.core.util import OrderedSet
 
+
 class archive_tw_resources(Command):
     """
     Setuptools command to copy and optionally compress all static resources
@@ -283,7 +284,6 @@ class JSResourceAggregator(ResourceAggregator):
     pass
 
 
-
 class CSSResourceAggregator(ResourceAggregator):
     """
     This class allows to splice in the abl.cssprocessor.CSSRewriter
@@ -305,7 +305,6 @@ class CSSResourceAggregator(ResourceAggregator):
             output = URI(filename)
             self.rewriter = CSSRewriter(output)
 
-
     def add_file(self, modname, filename):
         super(CSSResourceAggregator, self).add_file(modname, filename)
         if self.use_css_rewriter:
@@ -313,13 +312,11 @@ class CSSResourceAggregator(ResourceAggregator):
             css_file = URI(self.resolve_filename(modname, filename))
             self.rewriter.add_css(css_file)
 
-
     def flush(self):
         super(CSSResourceAggregator, self).flush()
         if self.use_css_rewriter:
             self.rewriter.rewrite()
 
-
     def post_hook(self, out_filename):
         if self.use_css_rewriter:
             from abl.vpath import URI
@@ -331,7 +328,7 @@ class CSSResourceAggregator(ResourceAggregator):
 
 class aggregate_tw_resources(Command):
     """
-    Setuptools commmand to aggregate Javascript- or CSS-files to one large
+    Setuptools command to aggregate Javascript- or CSS-files to one large
     file, possibly compressed through the use of YUICompressor.
 
     To enable compression of CSS and JS files you will need to have installed a
@@ -545,7 +542,7 @@ class aggregate_tw_resources(Command):
             resource_aggregator.add_file(modname, filename)
 
         if resource_aggregator:
-            # make the aggregator do it's acutal work.
+            # make the aggregator do it's actual work.
             # this must result in an existing variant_filename
             resource_aggregator.flush()
             inf = open(variant_filename)
@@ -586,7 +583,6 @@ class FileWriter(object):
         shutil.copyfileobj(stream, dest)
         dest.close()
 
-
     # Delegate methods to Command
     for name in "warn announce error execute".split():
         exec """\
@@ -594,6 +590,7 @@ def %(name)s(self, *args, **kw):
     return self.cmd.%(name)s(*args, **kw)
 """ % locals()
 
+
 class CompressingWriter(FileWriter):
 
     def __init__(self, *args, **kw):
@@ -646,6 +643,7 @@ class CompressingWriter(FileWriter):
         stream = self.compress(stream, path)
         return super(CompressingWriter, self).write_file(stream, path)
 
+
 class OnePassCompressingWriter(CompressingWriter):
     def __init__(self, *args, **kw):
         super(OnePassCompressingWriter, self).__init__(*args, **kw)
@@ -671,7 +669,7 @@ class OnePassCompressingWriter(CompressingWriter):
                 buffer.write(line)
 
     def finalize(self):
-        self.announce("Compressing all defered files")
+        self.announce("Compressing all deferred files")
         for typ, cache in self._caches.iteritems():
             cache.seek(0)
             # self.compress only wants to know the file extension to see
@@ -687,5 +685,5 @@ class OnePassCompressingWriter(CompressingWriter):
             self.announce("Will not consider %s for onepass" % path)
             return CompressingWriter.write_file(self, stream, path, require_once)
         print >> cache, self._marker % locals()
-        self.announce("Defering %s for compression in one pass" % path)
+        self.announce("Deferring %s for compression in one pass" % path)
         shutil.copyfileobj(stream, cache)
