@@ -25,7 +25,7 @@ def attrs(context, args=None, attrs=None):
 
     bools = _BOOLEAN_ATTRS
 
-    return u" ".join([u'%s="%s"' % (k, escape(unicode(k in bools and k or v)))
+    return u" ".join([u'%s="%s"' % (k, escape(unicode(k in bools and k or v), True))
                       for k,v in args
                       if (k not in bools and v is not None) or (k in bools and v)])
 
@@ -36,6 +36,7 @@ def content(context, value):
     else:
         return escape(unicode(value))
 
+
 def safe_str(context, value):
     """Converts value to its string representation, if unicode it makes it ascii
     safe by converting characters above 128 to their <128 equivalents."""
