@@ -3,6 +3,7 @@ from urllib import unquote
 import pkg_resources
 
 from webob import Request
+from webob.exc import HTTPNotFound
 
 import tw
 from tw.mods import base
@@ -12,6 +13,7 @@ from tw.core.server import always_deny
 
 __all__ = ["ToscaWidgetsMiddleware", "make_middleware"]
 
+
 class ToscaWidgetsMiddleware(object):
     """
     This WSGI middleware piece takes care of creating a per-request context for
@@ -20,12 +22,13 @@ class ToscaWidgetsMiddleware(object):
     It can also take care of serving those resources if `serve_resources` is
     True (default).
     """
+
     def __init__(self, application, host_framework, prefix='/toscawidgets',
                  inject_resources=True, serve_resources=True, require_once=False,
                  render_filter=None,
                  callback_security_default=always_deny,
                  ):
-        self.callback_security_default = callback_security_default        
+        self.callback_security_default = callback_security_default
         self.host_framework = host_framework
         self.host_framework.middleware = self
         self.prefix = prefix
@@ -51,39 +54,46 @@ class ToscaWidgetsMiddleware(object):
         environ.setdefault('toscawidgets.javascript.require_once', self.require_once)
 
         req = Request(environ)
+
         try:
             tw.framework.script_name = req.script_name
             if self.serve_resources and req.path_info.startswith(self.prefix):
                 # Intercept request to possibly serve a static resource
-                req.path_info = req.path_info[len(self.prefix):]
-                req.script_name += self.prefix
+                path_info = req.path_info[len(self.prefix):]
+                script_name = req.script_name + self.prefix
                 resources_app = resources.registry
-                if req.path_info.startswith(resources_app.prefix):
-                    req.path_info = req.path_info[len(resources_app.prefix):]
-                    req.script_name += resources_app.prefix
+                if path_info.startswith(resources_app.prefix):
+                    req.path_info = path_info[len(resources_app.prefix):]
+                    req.script_name = script_name + resources_app.prefix
                     resp = req.get_response(resources_app)
                     return resp(environ, start_response)
             else:
                 # Pass request downstream
                 resp = req.get_response(self.application)
-            return resp(environ, start_response)
+            if 'resp' in locals():
+                return resp(environ, start_response)
+            else:
+                return HTTPNotFound('There is no such resource')(environ, start_response)
         finally:
             self.host_framework.end_request(environ)
 
 #TODO: Wrap to issue deprecation warnings
 TGWidgetsMiddleware = ToscaWidgetsMiddleware
 
+
 def _load_from_entry_point(name):
     for ep in pkg_resources.iter_entry_points('toscawidgets.host_frameworks'):
         if ep.name == name:
             return ep
 
+
 def _extract_args(args, prefix, adapters={}):
     l = len(prefix)
     nop = lambda v: v
     return dict((k[l:], adapters.get(k[l:], nop)(v))
                 for k,v in args.iteritems() if k.startswith(prefix))
 
+
 def _load_host_framework(host_framework):
     if ':' not in host_framework:
         ep = _load_from_entry_point(host_framework)
@@ -97,6 +107,7 @@ def _load_host_framework(host_framework):
         raise LookupError("Could not load %s" % host_framework)
     return hf
 
+
 def make_middleware(app, config=None, **kw):
     """
     Initializes :class:`tw.core.middleware.ToscaWidgetsMiddleware` and a
@@ -111,7 +122,7 @@ def make_middleware(app, config=None, **kw):
     toscawidgets.middleware.*
         These parameters will be passed to
         :class:`tw.core.middleware.ToscaWidgetsMiddleware`
-        when instatntiating it. See its docstrings for details.
+        when instantiating it. See its docstrings for details.
 
     toscawidgets.framework
         Name of the ``toscawidgets.host_frameworks`` entry point or
