@@ -6,10 +6,11 @@ import string
 import heapq
 import mimetypes
 from operator import itemgetter
-from itertools import izip, chain, imap
+from itertools import chain, imap
 
 from pkg_resources import resource_filename, working_set, Requirement, \
                           resource_stream
+
 import tw
 from tw.core.base import Widget
 from tw.core.util import Enum, OrderedSet, RequestLocalDescriptor, asbool
@@ -27,8 +28,6 @@ __all__ = [
 log = logging.getLogger(__name__)
 
 
-
-
 class VariantedUrl(object):
 
     def __init__(self, url_mapping):
@@ -297,6 +296,7 @@ class _JavascriptFileIter(_FileIter):
 
 
 registry = ResourcesApp()
+
 """
 A single instance of the ResourcesApp, used by all TW-code.
 
@@ -305,6 +305,7 @@ setting ``tw.core.resources.registry.ACTIVE_VARIANT`` to one of the recognized
 values.
 """
 
+
 #------------------------------------------------------------------------------
 # Base class for all resources
 #------------------------------------------------------------------------------
@@ -321,7 +322,7 @@ class Resource(Widget):
         locations can be queried at ``Resource.valid_locations``
     """
 
-    valid_locations = Enum('head','headbottom', 'bodytop', 'bodybottom')
+    valid_locations = Enum('head', 'headbottom', 'bodytop', 'bodybottom')
     location = valid_locations.head
 
     def add_for_location(self, location):
@@ -339,6 +340,7 @@ class Resource(Widget):
 
 locations = Resource.valid_locations
 
+
 #------------------------------------------------------------------------------
 # Utility Mixins
 #------------------------------------------------------------------------------
@@ -373,7 +375,6 @@ class IEMixin:
 # Links
 #------------------------------------------------------------------------------
 
-
 class Link(Resource):
     """
     A link to an external resource, like a a JS or CSS file stored in the
@@ -501,17 +502,16 @@ class JSLink(Link, JSMixin):
         d.require_once = require_once
 
 
-
 class IEJSLink(JSLink, IEMixin):
     def update_params(self, d):
         JSLink.update_params(self, d)
         self._extend_template(d)
 
+
 #------------------------------------------------------------------------------
 # Raw source Resources
 #------------------------------------------------------------------------------
 
-
 class Source(Resource):
     """
     An inlined chunk of source code
@@ -548,7 +548,6 @@ class Source(Resource):
                "into a dictionary to provide values to fill in."
         }
 
-
     def __new__(cls, *args, **kw):
         """Support positional params. (src)"""
         src = None
@@ -580,8 +579,6 @@ class Source(Resource):
         return self.src == getattr(other, "src", None)
 
 
-
-
 class CSSSource(Source, CSSMixin):
     """
     An inlined chunk of CSS source code.
@@ -607,7 +604,6 @@ class IEJSSource(JSSource, IEMixin):
         self._extend_template(d)
 
 
-
 class JSFunctionCalls(JSSource):
     params = ["function_calls"]
     function_calls = []
@@ -617,7 +613,6 @@ class JSFunctionCalls(JSSource):
         self.src = "\n%s\n" % "\n".join(map(str, self.function_calls))
 
 
-
 class JSDynamicFunctionCalls(JSFunctionCalls):
     params = ["call_getter"]
     call_getter = lambda s, location: []
@@ -639,7 +634,6 @@ class JSDynamicFunctionCalls(JSFunctionCalls):
 
 # Utilities to retrieve resources
 
-
 def merge_resources(to, from_):
     """
     In-place merge all resources from ``from_`` into ``to``. Resources
@@ -651,6 +645,7 @@ def merge_resources(to, from_):
             to.setdefault(k, OrderedSet()).add_all(from_location)
     return to
 
+
 def retrieve_resources(obj):
     """Recursively retrieve resources from obj"""
     ret = {}
@@ -662,8 +657,11 @@ def retrieve_resources(obj):
         ret = reduce(merge_resources, imap(retrieve_resources, iter(obj)), {})
     return ret
 
+
 class DynamicCalls(object):
+
     _calls_for_request = RequestLocalDescriptor('_calls_for_request')
+
     def __init__(self):
         self.call_widgets = {}
         for l in locations:
@@ -699,7 +697,6 @@ class AggregatedJSLink(JSLink):
     It makes sure that the archive_tw_resources-command
     won't pick them up.
     """
-    pass
 
 
 class AggregatedCSSLink(CSSLink):
@@ -710,4 +707,4 @@ class AggregatedCSSLink(CSSLink):
     It makes sure that the archive_tw_resources-command
     won't pick them up.
     """
-    pass
+
