@@ -1,12 +1,10 @@
 import inspect
 import re
-import sys
 import warnings
 import time
 import weakref
 
-from itertools import count, izip
-
+from itertools import izip
 
 
 __all__ = [
@@ -18,8 +16,23 @@ __all__ = [
     "disable_runtime_checks",
     ]
 
+
 # Stolen from PasteDeploy
 def asbool(obj):
+    """Interpret a string as a boolean value, recognizing all usual values.
+
+    Examples::
+
+        >>> asbool('true')
+        True
+        >>> asbool('false')
+        False
+        >>> asbool('ON')
+        True
+        >>> asbool('OFF')
+        False
+
+    """
     if isinstance(obj, (str, unicode)):
         obj = obj.strip().lower()
         if obj in ['true', 'yes', 'on', 'y', 't', '1']:
@@ -27,31 +40,29 @@ def asbool(obj):
         elif obj in ['false', 'no', 'off', 'n', 'f', '0']:
             return False
         else:
-            raise ValueError(
-                "String is not true/false: %r" % obj)
+            raise ValueError("String is not true/false: %r" % obj)
     return bool(obj)
 
 
 def assert_bool_attr(name, state, exc):
-    """
-    Raises 'exc' if given flag is not equal to 'state'.
-    """
+    """Raise 'exc' if given flag is not equal to 'state'."""
+
     def entangle(func):
+
         def wrapper(self, *args, **kw):
             if getattr(self,name) == state:
                 return func(self, *args, **kw)
             raise exc
+
         wrapper.func_name = func.func_name
         wrapper.__dict__ = func.__dict__.copy()
         return wrapper
+
     return entangle
 
 
-
-
 def pre_post_wrapper(pre=None, post=None, lock=None):
-    """
-    Decorates a method excecuting pre and post methods around it.
+    """Decorate a method excecuting pre and post methods around it.
 
     Can be used to decorate the same method in different subclasses and takes
     care that pre is executed only once at the first cooperative call and post
@@ -85,10 +96,12 @@ def pre_post_wrapper(pre=None, post=None, lock=None):
         >>> exits
         1
 
-    A reentrant lock can be passed to syncronize the wrapped method. It is a
-    must if the instance is shared among several threads.
+    A reentrant lock can be passed to synchronize the wrapped method.
+    It is a must if the instance is shared among several threads.
+
     """
     def entangle(func):
+
         def wrapper(self, *args, **kw):
             counter_name = '__%s_wrapper_counter' % func.func_name
             if lock:
@@ -103,18 +116,25 @@ def pre_post_wrapper(pre=None, post=None, lock=None):
                 setattr(self, counter_name, counter - 1)
                 if counter == 1:
                     delattr(self, counter_name)
-                    if post: post(self, *args, **kw)
+                    if post:
+                        post(self, *args, **kw)
             finally:
                 if lock:
                     lock.release()
             return output
+
         wrapper.func_name = func.func_name
         wrapper.__dict__ = func.__dict__.copy()
         return wrapper
+
     return entangle
 
+
 def pre_post_hooks(pre_name=None, post_name=None, lock=None):
+    """Similar to pre_post_wrappe(), but using hook names."""
+
     def entangle(func):
+
         def wrapper(self, *args, **kw):
             counter_name = '__%s_wrapper_counter' % func.func_name
             bases = list(inspect.getmro(self.__class__))
@@ -145,21 +165,26 @@ def pre_post_hooks(pre_name=None, post_name=None, lock=None):
                 if lock:
                     lock.release()
             return output
+
         wrapper.func_name = func.func_name
         wrapper.__dict__ = func.__dict__.copy()
         return wrapper
+
     return entangle
 
+
 class CachedInspect(object):
-    """
-    In general "inspect" calls are extremely expensive.  However, if we cache them
-    on an object by object basis, we should be able to speed things up a 
+    """Cached inspect calls.
+
+    In general "inspect" calls are extremely expensive.  However, if we cache
+    them on an object by object basis, we should be able to speed things up.
+
     """
     def __init__(self):
         self.functions = weakref.WeakKeyDictionary()
         self.methods = weakref.WeakKeyDictionary()
         self.argspec = weakref.WeakKeyDictionary()
-    
+
     def is_function(self, obj):
         truth = self.functions.get(obj, None)
         if truth is None:
@@ -171,74 +196,111 @@ class CachedInspect(object):
         if truth is None:
             truth = self.methods[obj] = inspect.ismethod(obj)
         return truth
-    
+
     def getargspec(self, obj):
         spec = self.argspec.get(obj, None)
         if spec is None:
             spec = self.argspec[obj] = inspect.getargspec(obj)
         return spec
+
 callable_cache = CachedInspect()
 
+
 def callable_wo_args(obj):
-    if callable(obj) and (callable_cache.is_function(obj) or callable_cache.is_method(obj)):
+    """Check if object is callable without arguments."""
+    if callable(obj) and (callable_cache.is_function(obj)
+            or callable_cache.is_method(obj)):
         argspec = callable_cache.getargspec(obj)
         args = argspec[0]
         defaults = argspec[3]
         arg_length = callable_cache.is_method(obj) and 1 or 0
-        return (
-            (args is not None and (len(args) == arg_length)) or
-            (defaults is not None and len(args) == len(defaults))
-            )
+        return (args is not None and len(args) == arg_length) or (
+            defaults is not None and len(args) == len(defaults))
     return False
 
 
-
-_id_RE = re.compile(r'(\w+)+(?:-(\d))*')
 def unflatten_args(child_args):
-    new = {}
-    for k,v in child_args.iteritems():
-        splitted = k.split('.',1)
-        id = splitted[0]
-        if len(splitted) == 2:
-            rest = splitted[1]
-            if not id:
-                new[rest] = v
-                continue
-            for_id = new.setdefault(id, {})
-            for_id.setdefault('child_args', {})[rest] = v
+    """Create a nested directory from a directory with flattened keys.
+
+    Example::
+
+        >>> child_args = {'name': {'error': 'no name!'},
+        ...     'name.type': {'options': [(0, 'user'), (1, 'admin')]},
+        ...     'mail': {'error': 'invalid mail address!'},
+        ...     'mail-0': {'maxlength': 200},
+        ...     'mail-1': {'maxlength': 100},
+        ...     'tel': {'error': 'invalid phone number!'},
+        ...     'tel-0.type': {'options': [(0, 'fixed')]},
+        ...     'tel-1.type': {'options': [(0, 'fixed'), (1, 'mobile')]}}
+        >>> unflatten_args(child_args) == {
+        ...     'name': {'error': 'no name!', 'child_args': {
+        ...         'type': {'options': [(0, 'user'), (1, 'admin')]}}},
+        ...     'mail': {'error': 'invalid mail address!', 'child_args': [
+        ...         {'maxlength': 200}, {'maxlength': 100}]},
+        ...     'tel': {'error': 'invalid phone number!', 'child_args': [
+        ...         {'child_args': {'type': {'options':
+        ...             [(0, 'fixed')]}}},
+        ...         {'child_args': {'type': {'options':
+        ...             [(0, 'fixed'), (1, 'mobile')]}}}]}}
+        True
+
+    """
+    splitted_args = {}
+    sizes = {}
+    for key, value in child_args.iteritems():
+        splitted = key.split('.', 1)
+        if len(splitted) > 1:
+            key, subkey = splitted
         else:
-            for_id = new.setdefault(id,{})
-            for key, val  in v.iteritems():
-                for_id.setdefault(key,val)
-
-    convert = set()
-    for k,v in new.items():
-        m = _id_RE.match(k)
-        if not m:
-            raise ValueError(
-                "%r is not a valid id to reference a child" % k
-                )
-        id, n = m.groups()
-        if n is not None:
-            new.pop(k,None)
-            convert.add(id)
-            for_id = new.setdefault(id, {})
-            for_id[int(n)] = v
-
-    for k in convert:
-        for_k = new[k]
-        l = []
-        for n in count():
-            l.append(for_k.pop(n, {}))
-            if not for_k: break
-        new[k] = {'child_args':l}
-    return new
-
-
+            subkey = None
+        splitted = key.rsplit('-', 1)
+        if len(splitted) > 1 and splitted[1].isdigit():
+            key, nr = splitted[0], int(splitted[1])
+            if nr >= sizes.get(key, 0):
+                sizes[key] = nr + 1
+        else:
+            nr = None
+        splitted_args.setdefault(key, {}).setdefault(nr, {})[subkey] = value
+    nested_args = {}
+    for key, value in splitted_args.iteritems():
+        nested_args[key] = key_args = {}
+        if None in value:
+            for subkey, v in value[None].iteritems():
+                if subkey is None:
+                    key_args.update(v)
+                else:
+                    key_args.setdefault('child_args', {})[subkey] = v
+        if key in sizes:
+            key_args['child_args'] = child_list = []
+            for nr in xrange(sizes[key]):
+                key_args = dict()
+                if nr in value:
+                    for subkey, v in value[nr].iteritems():
+                        if subkey is None:
+                            key_args.update(v)
+                        else:
+                            key_args.setdefault('child_args', {})[subkey] = v
+                child_list.append(key_args)
+    return nested_args
 
 
 class OrderedSet(list):
-    """Set preserving item order."""
+    """Set preserving item order.
+
+    Example::
+
+        >>> s = OrderedSet()
+        >>> s.add_all(range(3))
+        >>> s
+        [0, 1, 2]
+        >>> s.add(3)
+        >>> s
+        [0, 1, 2, 3]
+        >>> s.add(2)
+        >>> s
+        [0, 1, 2, 3]
+
+    """
 
     def add(self, item):
         if item not in self:
@@ -249,18 +311,26 @@ class OrderedSet(list):
             self.add(item)
 
 
-class _RaiseAttributeError: pass
+class _RaiseAttributeError:
+    """Internal default value."""
+
 
 class ThreadSafeDescriptor(object):
     """Base class for threadsafe widget descriptors."""
 
+
 class RequestLocalDescriptor(ThreadSafeDescriptor):
-    """A descriptor that proxies to tw.framework.request_local for
-    passing state among widgets in a thread-safe manner for the current request.
+    """Request local descriptor.
+
+    A descriptor that proxies to tw.framework.request_local for passing
+    state among widgets in a thread-safe manner for the current request.
 
     Do not abuse this or code can become increasingly unmantainable!
+
     """
-    def __init__(self, name, default=_RaiseAttributeError, __doc__=None, qualify_with_id=False):
+
+    def __init__(self, name, default=_RaiseAttributeError,
+            __doc__=None, qualify_with_id=False):
         """Proxy to request local storage attribute named by ``name``.
 
         If ``default`` is provided no AttributeError will be raised if attribute
@@ -271,6 +341,7 @@ class RequestLocalDescriptor(ThreadSafeDescriptor):
 
         This prevents the collapsing of namespaces for several forms on one page
         being rendered after validation.
+
         """
         self.name = name
         self.default = default
@@ -306,7 +377,6 @@ class RequestLocalDescriptor(ThreadSafeDescriptor):
         name = self.name
         if self.qualify_with_id:
             name += "_%i" % id(obj)
-
         setattr(request_local, name, value)
 
     def __delete__(self, obj):
@@ -315,7 +385,6 @@ class RequestLocalDescriptor(ThreadSafeDescriptor):
         name = self.name
         if self.qualify_with_id:
             name += "_%i" % id(obj)
-
         try:
             delattr(request_local, name)
         except AttributeError:
@@ -324,6 +393,7 @@ class RequestLocalDescriptor(ThreadSafeDescriptor):
 
 
 def install_framework(force=False):
+    """Install the ToscaWidgets Framework."""
     import tw
     if not hasattr(tw, 'framework') or force:
         from tw.core.registry import StackedObjectProxy, Registry
@@ -335,18 +405,25 @@ def install_framework(force=False):
         dummy_framework.start_request({
             'SCRIPT_NAME': '',
             'toscawidgets.prefix': '/toscawidgets',
-            'paste.registry' : dummy_registry,
-        })
+            'paste.registry' : dummy_registry})
         tw.framework = StackedObjectProxy(
-            dummy_framework,
-            name='ToscaWidgetsFramework',
-            )
+            dummy_framework, name='ToscaWidgetsFramework')
+
 
 class Enum(dict):
-    """Less strict Enum than the one provided by TG"""
+    """Less strict Enum than the one provided by TurboGears.
+
+    Example::
+
+       >>> enum = Enum('apple', 'banana', 'peach')
+       >>> [e for e in sorted(enum)]
+       ['apple', 'banana', 'peach']
+
+    """
+
     def __init__(self, *args):
         for arg in args:
-            self[arg]= arg
+            self[arg] = arg
 
     def __getattr__(self, name):
         try:
@@ -354,7 +431,29 @@ class Enum(dict):
         except KeyError:
             raise AttributeError(name)
 
+
 class Bunch(dict):
+    """Simple but handy collector of a bunch of named stuff.
+
+    Example::
+
+        >>> bunch = Bunch(apple=2, banana=3, peach=1)
+        >>> bunch.banana
+        3
+        >>> bunch.banana = 4
+        >>> bunch.banana
+        4
+        >>> delattr(bunch, 'apple')
+        >>> hasattr(bunch, 'apple')
+        False
+        >>> hasattr(bunch, 'banana')
+        True
+        >>> bunch.peach -= 1
+        >>> bunch.peach
+        0
+
+    """
+
     __setattr__ = dict.__setitem__
 
     def __delattr__(self, name):
@@ -369,17 +468,15 @@ class Bunch(dict):
         except KeyError:
             raise AttributeError(name)
 
+
 def make_bunch(d):
-    """Converts a dict instance into a Bunch"""
+    """Convert a dict instance into a Bunch."""
     return Bunch(d)
 
 
-
-# Adapted form turbogears'
-
+# Adapted form TurboGears
 class lazystring(object):
-    """Has a number of lazily evaluated functions replicating a string.
-    """
+    """Has a number of lazily evaluated functions replicating a string."""
 
     def __init__(self, string):
         self.string = string
@@ -403,6 +500,7 @@ class lazystring(object):
     def __eq__(self, other):
         return self.eval() == other
 
+
 class MultipleReplacer(object):
     """Performs several regexp substitutions on a string with a single pass.
 
@@ -429,6 +527,7 @@ class MultipleReplacer(object):
         ...     before_c = "3"
         ...     ))
         'aaaa1bbb23cc'
+
     """
     def __init__(self, dct, options=0):
         self._raw_regexp = r"|".join("(%s)" % k for k in dct.keys())
@@ -451,21 +550,28 @@ class MultipleReplacer(object):
 
 
 def iwarn(iterable, message, category=None, stacklevel=1):
-    """Make an iterator that run warnings.warn(message, category, stacklevel)
+    """Create an Iterator that prints a warning.
+
+    Make an iterator that run warnings.warn(message, category, stacklevel)
     right before the first value from iterator is returned.
+
     """
     warnings.warn(message, category, stacklevel)
     for x in iterable:
         yield x
 
+
 # Stolen from Mako
 class LRUCache(dict):
-    """A dictionary-like object that stores a limited number of items, discarding
+    """Cache based on last recent usage.
+
+    A dictionary-like object that stores a limited number of items, discarding
     lesser used items periodically.
 
-    this is a rewrite of LRUCache from Myghty to use a periodic timestamp-based
-    paradigm so that synchronization is not really needed.  the size management
+    This is a rewrite of LRUCache from Myghty to use a periodic timestamp-based
+    paradigm so that synchronization is not really needed.  The size management
     is inexact.
+
     """
 
     class _Item(object):
@@ -512,22 +618,26 @@ class LRUCache(dict):
                 try:
                     del self[item.key]
                 except KeyError:
-                    # if we couldnt find a key, most likely some other thread broke in
-                    # on us. loop around and try again
+                    # If we couldn't find a key, most likely some other
+                    # thread broke in on us. Loop around and try again.
                     break
 
+
 def disable_runtime_checks():
-    """
+    """Disable runtime checks.
+
     Disables runtime checks for possible programming errors regarding
     modifying widget attributes once a widget has been initialized.
     This option can significantly reduce Widget initialization time.
     NOTE: This operation modifies the Widget class and will affect any
-        application using ToscaWidgets in the same process.
+    application using ToscaWidgets in the same process.
+
     """
     from tw.api import Widget
     del Widget.__setattr__
     del Widget.__delattr__
 
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
